@@ -6,14 +6,17 @@ use strict;
 
 my $mw = MainWindow->new;
 
+my $l = $mw->Label->pack;
+
 my $frog;
 my $lcd = $mw->LCD(-elements => 11, -variable => \$frog)->pack;
 
+$l->configure(-text => 'Large Numbers');
 $lcd->set(-1234567890);
-$mw->idletasks; $mw->after(3000);
+$mw->update; $mw->after(5000);
 
 $lcd->configure(qw/
-    -elements   4
+    -elements   15
     -background white 
     -onoutline  blue
     -onfill     blue
@@ -21,6 +24,12 @@ $lcd->configure(qw/
     -offfill    white
     -size       small
 /);
-$frog = 2002;
+$l->configure(-text => 'Small Numbers, Commified');
+$frog = 1_234_567_890.31415;
+$mw->update; $mw->after(5000);
+
+$lcd->configure(-elements => 4, -commify => 0);
+$l->configure(-text => 'Small Numbers, Not Commified');
+$frog = 2003;
 
 MainLoop;
